@@ -22,6 +22,8 @@ typedef SSIZE_T ssize_t;
 
 #endif
 
+#include <cmath>
+
 #include <vlc/vlc.h>
 #include <vlc/libvlc_version.h>
 
@@ -223,8 +225,8 @@ void AudioWrapper::setVolume(qreal volume)
         return;
     }
 
-    //auto realVolume = static_cast<qreal>(QAudio::convertVolume(volume / 100.0, QAudio::LogarithmicVolumeScale, QAudio::LinearVolumeScale));
-    libvlc_audio_set_volume(d->mPlayer, qRound(volume));
+    const int intVolume = std::clamp(qRound(volume), 0, 100);
+    libvlc_audio_set_volume(d->mPlayer, intVolume);
 }
 
 void AudioWrapper::setSource(const QUrl &source)
@@ -301,6 +303,7 @@ void AudioWrapper::setPosition(qint64 position)
 #else
     libvlc_media_player_set_position(d->mPlayer, static_cast<float>(position) / d->mMediaDuration);
 #endif
+    Q_EMIT positionChanged(position);
 }
 
 void AudioWrapper::savePosition(qint64 position)
@@ -553,7 +556,7 @@ void AudioWrapperPrivate::signalVolumeChange(int newVolume)
         return;
     }
 
-    if (abs(int(mPreviousVolume - newVolume)) > 0.01) {
+    if (abs(int(mPreviousVolume - newVolume)) >= 1) {
         mPreviousVolume = newVolume;
 
         mParent->playerVolumeSignalChanges();
